# RampResponse


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**charges** | [**List[RampChargeResponse]**](RampChargeResponse.md) | Container for the rate plan charges that are considered as part of the ramp deal. | [optional] 
**description** | **str** | The short description of the ramp. | [optional] 
**id** | **str** | The ID of the ramp. | [optional] 
**intervals** | [**List[RampIntervalResponse]**](RampIntervalResponse.md) | Container for the intervals that the ramp is split into in its timeline. | [optional] 
**name** | **str** | The name of the ramp. | [optional] 
**number** | **str** | The number of the ramp. It is automaticcally generated by the billing system. | [optional] 
**subscription_number** | **str** | The number of the subscription that is considered as part of the ramp deal. | [optional] 

## Example

```python
from zuora_sdk.models.ramp_response import RampResponse

# TODO update the JSON string below
json = "{}"
# create an instance of RampResponse from a JSON string
ramp_response_instance = RampResponse.from_json(json)
# print the JSON string representation of the object
print(RampResponse.to_json())

# convert the object into a dict
ramp_response_dict = ramp_response_instance.to_dict()
# create an instance of RampResponse from a dict
ramp_response_from_dict = RampResponse.from_dict(ramp_response_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


